@@ -36,6 +36,7 @@ readonly BINDGEN_SOURCE_MODULES=(
         "ubrk"
         "ucal"
         "uclean"
+        "ucnv"
         "ucol"
         "udat"
         "udatpg"
@@ -69,6 +70,7 @@ readonly BINDGEN_ALLOWLIST_TYPES=(
         "UCol.*"
         "UCollation.*"
         "UCollator"
+        "UConverter.*"
         "UData.*"
         "UDate.*"
         "UDateTime.*"
@@ -105,6 +107,7 @@ readonly BINDGEN_ALLOWLIST_FUNCTIONS=(
         "u_.*"
         "ubrk_.*"
         "ucal_.*"
+        "ucnv_.*"
         "ucol_.*"
         "udat_.*"
         "udatpg_.*"
